A data frame with 11 variables: parent, sex, anasc, nascreg, ' cit, acom4c, studio, codeq, codequal, codesett, codeireg. There is an additional variable id that is the unique identifier for the data set.
Common models
This data set has one year's worth of data.
This data set joined with another year's worth of
is appropriate for performing various types of record linkage
and can be assessed by standard record linkage methods.